Learn R Programming

grmsem (version 1.1.0)

grmsem.biher: grmsem bivariate heritability estimation function.

Description

This function estimates the bivariate heritability.

Usage

grmsem.biher(ph, grmsem.var.out = NULL)

Arguments

ph

Phenotype file as R dataframe (columns: >=2 phenotypes, rows: ni individuals in the same order as G). No default.

grmsem.var.out

A grmsem.var object with unstandardised parameters (factor loadings). Default NULL.

Value

grmsem.biher returns a list object consisting of the following matrices:

VPO

observed phenotypic variance/covariance matrix

VA

estimated genetic variance

BIHER

estimated bivariate heritability (off-diagonals): VA / VPO

BIHER.se

standard error of estimated bivariate heritability

BIHER.Z

Z (wald) of estimated bivariate heritability

BIHER.p

p (Wald) of estimated bivariate heritability

Details

The grmsem.biher function estimates the bivariate heritability (DS, Cholesky, IP and IPC models) from the observed phenotype data and a grmsem.var object. All standard errors are derived with the Delta method.

Examples

Run this code
# NOT RUN {
#(runtime should be less than one minute)
# }
# NOT RUN {
out <- grmsem.fit(ph.small, G.small, LogL = TRUE, estSE = TRUE)
var.out <- grmsem.var(out)
grmsem.biher(ph.small, var.out)
# }

Run the code above in your browser using DataLab