grmsem.stpar returns a list object consisting of:
model.inlist of input parameters
stand.model.outdataframe of fitted grmsem model with standardised parameters and SEs
stVCOVstandardised variance/covariance matrix
knumber of phenotypes
ntotal number of observations across all phenotypes
modeltype of grmsem model
ph.nmsvector of phenotype names
model.in list of input parameters:
parta - genetic, e - residual parameters
labelparameter label
valuestarting values
freeparfree parameters
stand.model.out data.frame of fitted grmsem model with standardised parameters and SEs:
labelparameter label
estimatesstandardised estimated parameters
seSE
ZZ (Wald)
pp (Wald)